@@ -1,9 +1,4 @@
 
-test_that("deprecation warning", {
-  skip_on_cran() # not sure why, maybe to do with the 8 hour lifecycle thing?
-  expect_warning(knife(breaks = 1:3), "deprecated")
-})
-
 
 test_that("basic functionality", {
   k <- knife(breaks = 1:3)
@@ -15,7 +10,6 @@ test_that("basic functionality", {
   y <- c(1, 4, 7, 10, 15)
   expect_equivalent(k(y), chop(y, breaks = brk_quantiles(0.5)))
 
-
   k2 <- knife(breaks = 1:3, labels = lbl_seq())
   x <- 0.5 + 1:3
   expect_equivalent(k2(x), chop(x, breaks = 1:3, labels = lbl_seq()))
